1.3.0 (2020-08-12)
------------------

- Add support of Django 3.0 and 3.1.


Previous versions
-----------------

Changes in previous versions were not recorded. See Git history for
further details.
